summaryrefslogtreecommitdiffstats
path: root/webkit/tools/test_shell/webview_host.h
diff options
context:
space:
mode:
authoravi@google.com <avi@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-09 18:33:11 +0000
committeravi@google.com <avi@google.com@0039d316-1c4b-4281-b951-d872f2087c98>2008-09-09 18:33:11 +0000
commite0751dc32e9a2f42267df6583d6feea0815a9a1a (patch)
tree438c39a7f782c729b44b9b9cb538f802e270ce4d /webkit/tools/test_shell/webview_host.h
parent27e64ed028a384c7c605dc3a68b1d4b87bf6a9a9 (diff)
downloadchromium_src-e0751dc32e9a2f42267df6583d6feea0815a9a1a.zip
chromium_src-e0751dc32e9a2f42267df6583d6feea0815a9a1a.tar.gz
chromium_src-e0751dc32e9a2f42267df6583d6feea0815a9a1a.tar.bz2
Bulk fixes to get Mac Test Shell more compile-happy.
Review URL: http://codereview.chromium.org/1818 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@1909 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'webkit/tools/test_shell/webview_host.h')
-rw-r--r--webkit/tools/test_shell/webview_host.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/webkit/tools/test_shell/webview_host.h b/webkit/tools/test_shell/webview_host.h
index 146f6ab..9a1e719 100644
--- a/webkit/tools/test_shell/webview_host.h
+++ b/webkit/tools/test_shell/webview_host.h
@@ -2,11 +2,11 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef WEBKIT_TOOLS_TEST_SHELL_WEBVIEW_HOST_H__
-#define WEBKIT_TOOLS_TEST_SHELL_WEBVIEW_HOST_H__
-
-#include <windows.h>
+#ifndef WEBKIT_TOOLS_TEST_SHELL_WEBVIEW_HOST_H_
+#define WEBKIT_TOOLS_TEST_SHELL_WEBVIEW_HOST_H_
+#include "base/basictypes.h"
+#include "base/gfx/native_widget_types.h"
#include "base/gfx/rect.h"
#include "base/scoped_ptr.h"
#include "webkit/tools/test_shell/webwidget_host.h"
@@ -15,23 +15,24 @@ struct WebPreferences;
class WebView;
class WebViewDelegate;
// This class is a simple HWND-based host for a WebView
class WebViewHost : public WebWidgetHost {
public:
// The new instance is deleted once the associated HWND is destroyed. The
// newly created window should be resized after it is created, using the
// MoveWindow (or equivalent) function.
- static WebViewHost* Create(HWND parent_window,
+ static WebViewHost* Create(gfx::WindowHandle parent_window,
WebViewDelegate* delegate,
const WebPreferences& prefs);
WebView* webview() const;
protected:
+#if defined(OS_WIN)
virtual bool WndProc(UINT message, WPARAM wparam, LPARAM lparam) {
return false;
}
+#endif
};
-#endif // WEBKIT_TOOLS_TEST_SHELL_WEBVIEW_HOST_H__
-
+#endif // WEBKIT_TOOLS_TEST_SHELL_WEBVIEW_HOST_H_
@@ -15,23 +15,24 @@ struct WebPreferences;
class WebView;
class WebViewDelegate;
-// This class is a simple HWND-based host for a WebView
+// This class is a simple ViewHandle-based host for a WebView
class WebViewHost : public WebWidgetHost {
public:
@@ -15,23 +15,24 @@ struct WebPreferences;
class WebViewHost : public WebWidgetHost {
public:
- // The new instance is deleted once the associated HWND is destroyed. The
- // newly created window should be resized after it is created, using the
+ // The new instance is deleted once the associated ViewHandle is destroyed.
+ // The newly created window should be resized after it is created, using the
// MoveWindow (or equivalent) function.